==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nenhum contorno selecionado</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Contorno não fechado no ponto %1/%2.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cada entidade de contorno deve ser uma linha, arco, círculo, elipse arco, elipse, polilinha ou uma spline. Encontrados:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Hachura
Padrões de &amp;Hachura:</translatorcomment>
        <translation>&amp;Hachura</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Desenhe hachura ou preenchimento sólido</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
&amp;Hachura
Hachura
Desenhe hachurados e preenchimentos sólidos</translatorcomment>
        <translation>Hachura</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Tipo de linha:
Tipo de linha
Tipo Ordinal</translatorcomment>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Desenhe hachurados e preenchimentos sólidos
Hachuras / preenchimentos sólidos</translatorcomment>
        <translation>Preenchimento Sólido</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translatorcomment>--google--
Padrões de Hachura:
Padrões de Hachura</translatorcomment>
        <translation>Textura da Hachura</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Prévia de impressão para %1
Prévia de Impressão
Exibe uma prévia da impressão</translatorcomment>
        <translation>Pré-visualize</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: pt.po--
Padrão
Padrões de Hachura:</translatorcomment>
        <translation>Textura</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre o ângulo:
Insira o ângulo da linha de dimensão:</translatorcomment>
        <translation>Ângulo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Ampliar
Escala da Superfície</translatorcomment>
        <translation>Escala:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nenhum contorno selecionado</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Contorno não fechado no ponto %1/%2.</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Cada entidade de contorno deve ser uma linha, arco, círculo, elipse arco, elipse, polilinha ou uma spline. Encontrados:</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation>Ferramentas de hachura</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation>Exiba as ferramentas de hachura</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Hachura
Padrões de &amp;Hachura:</translatorcomment>
        <translation>&amp;Hachura</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Desenhe hachura ou preenchimento sólido</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
&amp;Hachura
Hachura
Desenhe hachurados e preenchimentos sólidos</translatorcomment>
        <translation>Hachura</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Tipo de linha:
Tipo de linha
Tipo Ordinal</translatorcomment>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Desenhe hachurados e preenchimentos sólidos
Hachuras / preenchimentos sólidos</translatorcomment>
        <translation>Preenchimento Sólido</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translatorcomment>--google--
Padrões de Hachura:
Padrões de Hachura</translatorcomment>
        <translation>Textura da Hachura</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Prévia de impressão para %1
Prévia de Impressão
Exibe uma prévia da impressão</translatorcomment>
        <translation>Pré-visualize</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: pt.po--
Padrão
Padrões de Hachura:</translatorcomment>
        <translation>Textura</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre o ângulo:
Insira o ângulo da linha de dimensão:</translatorcomment>
        <translation>Ângulo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Ampliar
Escala da Superfície</translatorcomment>
        <translation>Escala:</translation>
    </message>
</context>
</TS>
